.. _api-kotti.views:

kotti.views
-----------

.. automodule:: kotti.views
   :members:
   :member-order: bysource

.. toctree::
   :maxdepth: 3

   kotti.views.cache
   kotti.views.edit/index
   kotti.views.file
   kotti.views.form
   kotti.views.login
   kotti.views.site_setup
   kotti.views.slots
   kotti.views.users
   kotti.views.util
   kotti.views.view
